@@ -1,7 +1,7 @@
 """Constants package for PyVSS."""
 PACKAGE_NAME = "pyvss"
 
-__version__ = '0.16.0'
+__version__ = '0.17.0'
 
 API_ENDPOINT_BASE = 'https://cloud-api.eis.utoronto.ca'
 VSKEY_STOR_ENDPOINT = 'https://vskey-stor.eis.utoronto.ca'
@@ -140,3 +140,30 @@ VALID_VM_VMX = [
         "type": "vmx-7",
     },
 ]
+
+VALID_VM_EXTRA_CFG = [
+    {
+        "description": "Enable disk UUID on virtual machines",
+        "option": "disk.EnableUUID",
+    },
+    {
+        "description": "Enable content Copy/Paste between "
+        "VMRC client and Windows/Linux",
+        "option": "isolation.tools.copy.disable",
+    },
+    {
+        "description": "Enable content Copy/Paste between "
+        "VMRC client and Windows/Linux",
+        "option": "isolation.tools.paste.disable",
+    },
+    {
+        "description": "Enable content Copy/Paste between "
+        "VMRC client and Windows/Linux",
+        "option": "isolation.tools.setGUIOptions.enable",
+    },
+    {
+        "description": "You can use the guestinfo variables to "
+        "query information such as version and build information.",
+        "option": "guestinfo.",
+    },
+]
